<?php

namespace Drupal\media_entity_unsplash;

/**
 * Functions that can be used for the Unsplash API.
 */
interface UnsplashFetcherInterface {

  /**
   * Retrieves an image from Unsplash by its ID.
   *
   * @param string $url
   *   The image ID.
   *
   * @return false|object
   *   The tweet information.
   */
  public function fetchImage(string $url): object|bool;

  /**
   * Search for a photo based on a search string.
   *
   * @param string $searchString
   *   The search string.
   *
   * @return array
   *   The list of found photos.
   */
  public function searchPhoto(string $searchString): array;

  /**
   * Returns the current Unsplash API credentials.
   *
   * @return array
   *   The API credentials. This will be an array containing the
   *   application_id and the utm_source.
   */
  public function getCredentials(): array;

  /**
   * Sets the credentials for accessing Unsplash API.
   *
   * @param string $access_key
   *   The consumer key.
   * @param string $secret_key
   *   The utm source.
   */
  public function setCredentials(string $access_key, string $secret_key);

}
